cd "you work directory"
use "sample 3272.dta" 



********************************
******variable description******
********************************
***income
	/*lmthinc: personal income of last month*/
***time use
	/*wkdayall: monthly working days*/
	/*wkhrsall: daily working hours*/
***subjective: subjectall
	/*happiness: self-rated level of happiness*/	
	/*lifesat: self-rated level of life satisfaction*/	
	/*confidence: self-rated confidence in career*/	
	/*confuture: self-rated confidence in the future*/	
	/*rlship: self-rated quality of social relationship*/	
	/*social: self-rated social abilities*/	
****endogenous variables
	/*c1female: first child is a girl*/
	/*morechd: having more than one child*/
	/*nchd: number of children*/
****other variables
	/*gender*/
	/*agriculture: work in agriculture*/
	/*hukouprovince: province of hukou registration*/	
	/*migrant: whether currently a migrant*/	
	/*age*/	
	/*agefstbirth: age at first birth*/	
	/*minority: whether ethnic minority*/	
	/*edudmy21: illiterate/semi-illiterate*/	
	/*edudmy22: primary*/	
	/*edudmy23: junior middle*/	
	/*edudmy24: senior middle*/	
	/*edudmy25: associate college/above*/
	/*cagegap: age gap between oldest and youngest child*/
	/*ccoresidyog: whether coresiding with youngest child*/
	/*spcoresid: whether coresiding with spouse*/
	/*fanocoresid: not coresiding with father*/
	/*facoresidyoung: coresiding with father younger than 70*/
	/*facoresidold: coresiding with father older than 70*/
	/*manocoresid: not coresiding with mother*/
	/*macoresidyoung: coresiding with mother younger than 70*/
	/*macoresidold: coresiding with mother older than 70*/
	

***************************************************
******multiple imputations for missing values******
***************************************************
gen id=_n
//start imputation
set seed 12345
mi set mlong
mi misstable sum
mi register imputed lmthinc wkdayall wkhrsall wdaycare wndcare happiness confidence confuture social rlship
mi register regular lifesat ///
	 c1female morechd nchd ///
	 gender ///
	 agriculture hukouprovince migrant ///
	 age agefstbirth minority ///
	 edudmy21 edudmy22 edudmy23 edudmy24 edudmy25 ///
	 cagegap ccoresidyog spcoresid fanocoresid facoresidyoung facoresidold manocoresid macoresidyoung macoresidold
	 
mi impute mvn ///
   lmthinc wkdayall wkhrsall wdaycare wndcare happiness confidence confuture social rlship ///
   = lifesat ///
	 c1female morechd nchd ///
	 gender ///
	 agriculture hukouprovince migrant ///
	 age agefstbirth minority ///
	 edudmy21 edudmy22 edudmy24 edudmy25 ///
	 cagegap ccoresidyog spcoresid fanocoresid facoresidyoung facoresidold manocoresid macoresidyoung macoresidold, add(10)

*generate monthly working hours
gen mthwkhrs=wkdayall*wkhrsall
mi register passive mthwkhrs

*generate weekly hours taking care of family members
gen allwkcare=wdaycare*5+wndcare*2
mi register passive allwkcare

*generate overall subjective scale
gen subjectall=(happiness+lifesat+confidence+confuture+social+rlship)/6
mi register passive subjectall

*generate separate variables with imputed values
bysort _mi_id: egen i_lmthinc=mean(lmthinc)
bysort _mi_id: egen i_wkdayall=mean(wkdayall)
bysort _mi_id: egen i_wkhrsall=mean(wkhrsall)
bysort _mi_id: egen i_wdaycare=mean(wdaycare)
bysort _mi_id: egen i_wndcare=mean(wndcare)
bysort _mi_id: egen i_happiness=mean(happiness)
bysort _mi_id: egen i_confidence=mean(confidence)
bysort _mi_id: egen i_confuture=mean(confuture)
bysort _mi_id: egen i_social=mean(social)
bysort _mi_id: egen i_rlship=mean(rlship)

gen im_lmthinc=lmthinc
    replace im_lmthinc=i_lmthinc if lmthinc==.
gen im_wkdayall=wkdayall
    replace im_wkdayall=i_wkdayall if wkdayall==.
gen im_wkhrsall=wkhrsall
    replace im_wkhrsall=i_wkhrsall if wkhrsall==.
gen im_wdaycare=wdaycare
    replace im_wdaycare=i_wdaycare if wdaycare==.
gen im_wndcare=wndcare
    replace im_wndcare=i_wndcare if wndcare==.
gen im_happiness=happiness
    replace im_happiness=i_happiness if happiness==.
gen im_confidence=confidence
    replace im_confidence=i_confidence if confidence==.
gen im_confuture=confuture
    replace im_confuture=i_confuture if confuture==.
gen im_social=social
    replace im_social=i_social if social==.
gen im_rlship=rlship
    replace im_rlship=i_rlship if rlship==.
gen im_lifesat=lifesat

order pid id
keep if _mi_m==0

*income cannot be lower than zero
replace im_lmthinc=0 if im_lmthinc<0
*generate natural logarithm of imputed personal income last month
gen lnlmthinc=ln(im_lmthinc)
replace lnlmthinc=ln(im_lmthinc+0.01) if im_lmthinc==0

*generate monthly working hours based on imputed values
replace mthwkhrs=im_wkdayall*im_wkhrsall
*generate natural logarithm of imputed monthly working hours
gen lnmthwkhrs=ln(mthwkhrs)
*generate weekly hours taking care of family members based on imputed values
replace allwkcare=im_wdaycare*5+im_wndcare*2
*generate monthly hours taking care of family members based on imputed values
gen allmthcare=allwkcare*4
*generate natural logarithm of monthly hours taking care of family members based on imputed values
gen lnallmthcare=ln(allmthcare)
replace lnallmthcare=ln(allmthcare+0.01) if allmthcare==0
*generate overall subjective scale based on imputed values
replace subjectall=(im_happiness+im_lifesat+im_confidence+im_confuture+im_social+im_rlship)/6

*order the data for more efficient use
order pid id c1female morechd nchd gender ///
             lnlmthinc lnmthwkhrs lnallmthcare subjectall ///
			 im_happiness im_lifesat im_confidence im_confuture im_social im_rlship

// Analysis
// Table 1
****************
*****morechd****
****************
bysort c1female: su morechd if gender==1
reg morechd c1female if gender==1
bysort c1female: su morechd if gender==0
reg morechd c1female if gender==0

*******************
***# of children***
*******************
bysort c1female: su nchd if gender==1
reg nchd c1female if gender==1
bysort c1female: su nchd if gender==0
reg nchd c1female if gender==0

*****************
****lnmthwkhrs***
*****************
bysort c1female: su lnmthwkhrs if gender==1
reg lnmthwkhrs c1female if gender==1
bysort c1female: su lnmthwkhrs if gender==0
reg lnmthwkhrs c1female if gender==0

*****************
****lnallmthcare***
*****************
bysort c1female: su lnallmthcare if gender==1
reg lnallmthcare c1female if gender==1
bysort c1female: su lnallmthcare if gender==0
reg lnallmthcare c1female if gender==0

*****************
****lnlmthinc***
*****************
bysort c1female: su lnlmthinc if gender==1
reg lnlmthinc c1female if gender==1
bysort c1female: su lnlmthinc if gender==0
reg lnlmthinc c1female if gender==0

*****************
****subjectall***
*****************
bysort c1female: su subjectall if gender==1
reg subjectall c1female if gender==1
bysort c1female: su subjectall if gender==0
reg subjectall c1female if gender==0


// Table 2
***********************************
****OLS of fertility outcomes******
***********************************
tab hukouprovince, gen(hkprov)

******man
reg morechd c1female ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1

reg nchd c1female ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1


******womam	
reg morechd c1female ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0

reg nchd c1female ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0
	
	
*************************
****OLS of outcomes******
*************************
******man
reg lnmthwkhrs c1female ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1

reg lnallmthcare c1female ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1
	
reg lnlmthinc c1female ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1

reg subjectall c1female ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1
	
******womam	
reg lnmthwkhrs c1female ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0

reg lnallmthcare c1female ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0
	
reg lnlmthinc c1female ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0

reg subjectall c1female ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0


//Tables 3a and 4a
******man
*********************************
***working hours*****************
*********************************
ivreg lnmthwkhrs ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==1,nohe r

reg lnmthwkhrs morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1
	  

ivreg lnmthwkhrs ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==1,nohe r

reg lnmthwkhrs nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1

*****************************************************
***hours taking care of family members***************
*****************************************************
ivreg lnallmthcare ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==1,nohe r

reg lnallmthcare morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1
	  

ivreg lnallmthcare ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==1,nohe r

reg lnallmthcare nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1
	
******************************
***income*********************
******************************
ivreg lnlmthinc ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==1,nohe r

reg lnlmthinc morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1
	  

ivreg lnlmthinc ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==1,nohe r

reg lnlmthinc nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1
	
************************************
***subjectall scale*****************
************************************
ivreg subjectall ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==1,nohe r

reg subjectall morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1
	  

ivreg subjectall ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==1,nohe r

reg subjectall nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1
	  
	  
******woman
*********************************
***working hours*****************
*********************************
ivreg lnmthwkhrs ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==0,nohe r

reg lnmthwkhrs morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0
	  

ivreg lnmthwkhrs ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==0,nohe r

reg lnmthwkhrs nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0

*****************************************************
***hours taking care of family members***************
*****************************************************
ivreg lnallmthcare ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==0,nohe r

reg lnallmthcare morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0
	  

ivreg lnallmthcare ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==0,nohe r

reg lnallmthcare nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0
	
******************************
***income*********************
******************************
ivreg lnlmthinc ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==0,nohe r

reg lnlmthinc morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0
	  

ivreg lnlmthinc ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==0,nohe r

reg lnlmthinc nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0
	
************************************
***subjectall scale*****************
************************************
ivreg subjectall ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==0,nohe r

reg subjectall morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0
	  

ivreg subjectall ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==0,nohe r

reg subjectall nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0
	
//Tables 3b and 4b
******man
******************************
***happiness******************
******************************
ivreg im_happiness ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==1,nohe r

reg im_happiness morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1
	  

ivreg im_happiness ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==1,nohe r

reg im_happiness nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1	
	
*************************************
***life satisfaction*****************
*************************************
ivreg im_lifesat ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==1,nohe r

reg im_lifesat morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1
	  

ivreg im_lifesat ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==1,nohe r

reg im_lifesat nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1		

****************************************
***confidence in career*****************
****************************************
ivreg im_confidence ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==1,nohe r

reg im_confidence morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1
	  

ivreg im_confidence ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==1,nohe r

reg im_confidence nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1		

********************************************
***confidence in the future*****************
********************************************
ivreg im_confuture ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==1,nohe r

reg im_confuture morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1
	  

ivreg im_confuture ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==1,nohe r

reg im_confuture nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1		
	
**************************************************
***quality of social relationship*****************
**************************************************
ivreg im_rlship ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==1,nohe r

reg im_rlship morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1
	  

ivreg im_rlship ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==1,nohe r

reg im_rlship nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1		
	
**********************************
***social ability*****************
**********************************
ivreg im_social ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==1,nohe r

reg im_social morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1
	  

ivreg im_social ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==1,nohe r

reg im_social nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==1		
	
******woman
******************************
***happiness******************
******************************
ivreg im_happiness ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==0,nohe r

reg im_happiness morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0
	  

ivreg im_happiness ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==0,nohe r

reg im_happiness nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0	
	
*************************************
***life satisfaction*****************
*************************************
ivreg im_lifesat ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==0,nohe r

reg im_lifesat morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0
	  

ivreg im_lifesat ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==0,nohe r

reg im_lifesat nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0		

****************************************
***confidence in career*****************
****************************************
ivreg im_confidence ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==0,nohe r

reg im_confidence morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0
	  

ivreg im_confidence ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==0,nohe r

reg im_confidence nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0		

********************************************
***confidence in the future*****************
********************************************
ivreg im_confuture ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==0,nohe r

reg im_confuture morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0
	  

ivreg im_confuture ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==0,nohe r

reg im_confuture nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0		
	
**************************************************
***quality of social relationship*****************
**************************************************
ivreg im_rlship ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==0,nohe r

reg im_rlship morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0
	  

ivreg im_rlship ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==0,nohe r

reg im_rlship nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0		
	
**********************************
***social ability*****************
**********************************
ivreg im_social ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (morechd=c1female) if gender==0,nohe r

reg im_social morechd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0
	  

ivreg im_social ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
    (nchd=c1female) if gender==0,nohe r

reg im_social nchd ///
	agriculture hkprov2-hkprov18 migrant ///
	age agefstbirth minority ///
	edudmy21 edudmy22 edudmy24 edudmy25 ///
	cagegap ccoresidyog spcoresid ///
	facoresidyoung facoresidold macoresidyoung macoresidold ///
	if gender==0		
	
	
//Appendix Table 2
**********************************************************
****Differences in Means for Demographic Variables********
**********************************************************
reg agriculture c1female if gender==1
reg agriculture c1female if gender==0

tab hukouprovince c1female if gender==1, chi
tab hukouprovince c1female if gender==0, chi

reg migrant c1female if gender==1
reg migrant c1female if gender==0

reg age c1female if gender==1
reg age c1female if gender==0

reg agefstbirth c1female if gender==1
reg agefstbirth c1female if gender==0

reg edudmy21 c1female if gender==1
reg edudmy21 c1female if gender==0

reg edudmy22 c1female if gender==1
reg edudmy22 c1female if gender==0

reg edudmy23 c1female if gender==1
reg edudmy23 c1female if gender==0

reg edudmy24 c1female if gender==1
reg edudmy24 c1female if gender==0

reg edudmy25 c1female if gender==1
reg edudmy25 c1female if gender==0

reg cagegap c1female if gender==1
reg cagegap c1female if gender==0

reg ccoresidyog c1female if gender==1
reg ccoresidyog c1female if gender==0

reg spcoresid c1female if gender==1
reg spcoresid c1female if gender==0

reg fanocoresid c1female if gender==1
reg fanocoresid c1female if gender==0

reg facoresidyoung c1female if gender==1
reg facoresidyoung c1female if gender==0

reg facoresidold c1female if gender==1
reg facoresidold c1female if gender==0

reg manocoresid c1female if gender==1
reg manocoresid c1female if gender==0

reg macoresidyoung c1female if gender==1
reg macoresidyoung c1female if gender==0

reg macoresidold c1female if gender==1
reg macoresidold c1female if gender==0


//Appendix Table 3
******man
reg   lnmthwkhrs morechd if gender==1
reg   lnmthwkhrs nchd if gender==1
ivreg lnmthwkhrs (morechd=c1female) if gender==1,nohe r
ivreg lnmthwkhrs (nchd=c1female) if gender==1,nohe r

reg   lnallmthcare morechd if gender==1
reg   lnallmthcare nchd if gender==1
ivreg lnallmthcare (morechd=c1female) if gender==1,nohe r
ivreg lnallmthcare (nchd=c1female) if gender==1,nohe r

reg   lnlmthinc morechd if gender==1
reg   lnlmthinc nchd if gender==1
ivreg lnlmthinc (morechd=c1female) if gender==1,nohe r
ivreg lnlmthinc (nchd=c1female) if gender==1,nohe r

reg   subjectall morechd if gender==1
reg   subjectall nchd if gender==1
ivreg subjectall (morechd=c1female) if gender==1,nohe r
ivreg subjectall (nchd=c1female) if gender==1,nohe r

******womam	
reg   lnmthwkhrs morechd if gender==0
reg   lnmthwkhrs nchd if gender==0
ivreg lnmthwkhrs (morechd=c1female) if gender==0,nohe r
ivreg lnmthwkhrs (nchd=c1female) if gender==0,nohe r

reg   lnallmthcare morechd if gender==0
reg   lnallmthcare nchd if gender==0
ivreg lnallmthcare (morechd=c1female) if gender==0,nohe r
ivreg lnallmthcare (nchd=c1female) if gender==0,nohe r

reg   lnlmthinc morechd if gender==0
reg   lnlmthinc nchd if gender==0
ivreg lnlmthinc (morechd=c1female) if gender==0,nohe r
ivreg lnlmthinc (nchd=c1female) if gender==0,nohe r

reg   subjectall morechd if gender==0
reg   subjectall nchd if gender==0
ivreg subjectall (morechd=c1female) if gender==0,nohe r
ivreg subjectall (nchd=c1female) if gender==0,nohe r
